pub struct TokioP2PNetworkClient { /* private fields */ }Implementations
Sourceimpl TokioP2PNetworkClient
impl TokioP2PNetworkClient
Sourcepub fn new(
name: impl Into<String>,
initial_peers: Vec<impl Into<String>>,
tokio: Option<Runtime>,
) -> Self
pub fn new( name: impl Into<String>, initial_peers: Vec<impl Into<String>>, tokio: Option<Runtime>, ) -> Self
Owns the passed runtime, using it only if no contextual handle is available;
if None is passed, it creates a runtime with multi-threaded support,
CPU-based thread pool size and all features enabled.