pub struct TokioP2PNetworkServer { /* private fields */ }Implementations
Sourceimpl TokioP2PNetworkServer
impl TokioP2PNetworkServer
Sourcepub fn new(
name: impl Into<String>,
socket: UdpSocket,
tokio: Option<Runtime>,
) -> Self
pub fn new( name: impl Into<String>, socket: UdpSocket, tokio: Option<Runtime>, ) -> Self
Owns the passed runtime, using it only if no contextual handle is available;
if None is passed, it creates a runtime with multi-threaded support,
CPU-based thread pool size and all features enabled.
pub fn start<UntypedMsgHandlerT: UntypedMsgHandler + 'static, MsgT, DeT>( &self, handler: UntypedMsgHandlerT, deserializer: DeT, buffer_size: usize, ) -> Result<TokioJoinHandle<()>>